mounts
======

#### Table of Contents

1. [Description](#description)
2. [Setup](#setup)
    1. [Requirements](#requirements)
3. [Usage](#usage)
4. [Reference](#reference)

Description
===========
Manage mounts via fstab and `mounts -a`.


Setup
=====
Pull in this module set mounts via hiera.

Requirements
------------

- Puppet Version >= 4
- puppetlabs/stdlib >= 4.12.0

Usage
=====
Example:

In manifest:
```puppet
include mounts
```

I set os specific settings in `79_%{os}` and general in `99_default`:

`79_Gentoo.yaml`:
```yaml
mounts:
  /var/tmp/paludis:
    fs: tmpfs
    opts:
      - uid=paludisbuild
      - gid=paludisbuild
      - mode=755
      - noatime
  /var/tmp/portage:
    fs: tmpfs
    opts:
      - uid=portage
      - gid=portage
      - mode=755
      - noatime
```

`99_default.yaml`:
```yaml
mounts:
  /tmp:
    fs: tmpfs
    opts:
      - defaults
      - nosuid
```

Reference
=========

### Classes

#### mounts
##### `fstab`

Path to fstab, defaults to `/etc/fstab`

##### `mode`

Mode for fstab, defaults to `0644`

##### `realize_tag`

Tag of `Mounts::Mount` to realize, defaults to `mounts`.

##### `mount_cmd`

Command to use to update mounts, defaults to `/bin/mount --all`.

### Defines

#### mounts::mount
##### `fs`

Filesystem to mount, required.

##### `mountpoint`

Namevar, path of mount.

##### `type`

Type of filesystem to mount. Defaults to `tmpfs` for `fs=tmpfs`, `ext4`
otherwise.

##### `opts`

Options to set, defaults to `['defaults']`.

##### `dump`

If the filesystem should be dumped, defaults to `0`.

##### `pass`

If and when the filesystem should be checked at boot time. Defaults to
`0` for tmpfs and `2` otherwise.

##### `order`

Order to pass to `concat::fragment`, used to order the filesystem within
the target fstab.
